import { PoolClient } from 'pg';
import { ExecutionResult } from 'graphql';
import { WithPostGraphileContextOptions } from '../interfaces';
import { GraphileResolverContext } from 'postgraphile-core';
export declare type WithPostGraphileContextFn<TResult = ExecutionResult> = (options: WithPostGraphileContextOptions, callback: (context: GraphileResolverContext) => Promise<TResult> | TResult) => Promise<TResult>;
/**
 * Creates a PostGraphile context object which should be passed into a GraphQL
 * execution. This function will also connect a client from a Postgres pool and
 * setup a transaction in that client.
 *
 * This function is intended to wrap a call to GraphQL-js execution like so:
 *
 * ```js
 * const result = await withPostGraphileContext({
 *   pgPool,
 *   jwtToken,
 *   jwtSecret,
 *   pgDefaultRole,
 * }, async context => {
 *   return await graphql(
 *     schema,
 *     query,
 *     null,
 *     { ...context },
 *     variables,
 *     operationName,
 *   );
 * });
 * ```
 */
declare function withPostGraphileContext<TResult = ExecutionResult>(options: WithPostGraphileContextOptions, callback: (context: GraphileResolverContext) => Promise<TResult> | TResult): Promise<TResult>;
export default withPostGraphileContext;
interface RawExplainResult {
    query: string;
    result: any;
}
declare type ExplainResult = Omit<RawExplainResult, 'result'> & {
    plan: string;
};
declare module 'pg' {
    interface ClientBase {
        _explainResults: Array<RawExplainResult> | null;
        startExplain: () => void;
        stopExplain: () => Promise<Array<ExplainResult>>;
    }
}
/**
 * Adds debug logging funcionality to a Postgres client.
 *
 * @private
 */
export declare function debugPgClient(pgClient: PoolClient, allowExplain?: boolean): PoolClient;
